| Title: | Melt Curve Fitting and Melt Shift Analysis |
|---|---|
| Description: | Analyzes raw abundance data from a cellular thermal shift experiment and calculates melt temperatures and melt shifts for each protein in the experiment. McCracken (2022) <doi:10.1101/2022.12.30.522131>. |
| Authors: | Neil McCracken [aut], Hao Liu [ctb], Amber Mosley [cre] |
| Maintainer: | Amber Mosley <[email protected]> |
| License: | GPL-2 |
| Version: | 1.6 |
| Built: | 2026-05-22 18:50:00 UTC |
| Source: | https://github.com/cran/InflectSSP |
This function corrects the normalized abundance of each protein using a correction constant that is calculated in this function. The correction constant is determined using the difference between actual and predicted fit at the proteome level.
Correction(PSM, UP, Data_CurveFit1Parameters, Data_Normalized, Data_Quantified)Correction(PSM, UP, Data_CurveFit1Parameters, Data_Normalized, Data_Quantified)
PSM |
the number of peptide spectrum matches that are deemed acceptable for reporting |
UP |
the number of unique peptides for a protein that are deemed acceptable for reporting |
Data_CurveFit1Parameters |
the parameters determined from Curve Fit 1 operation for proteome melts |
Data_Normalized |
the normalized abundance data for each protein determined in the Normalize function. |
Data_Quantified |
the median normalized abundance data at the proteome level |
the corrected and normalized abundance data for each protein
## Not run: Data_Corrected<-Correction(PSM,UP,Data_CurveFit1Parameters, Data_Normalized,Data_Quantified) ## End(Not run)## Not run: Data_Corrected<-Correction(PSM,UP,Data_CurveFit1Parameters, Data_Normalized,Data_Quantified) ## End(Not run)
This function determines the 4 parameter or 3 parameter log fit for the proteome level curve.
CurveFit1(Data_Quantified)CurveFit1(Data_Quantified)
Data_Quantified |
the median abundance values calculated in the Quantify function |
the curve fit parameters for the control and condition curves at the proteome level
## Not run: Data_CurveFit1Parameters<-CurveFit1(Data_Quantified) ## End(Not run)## Not run: Data_CurveFit1Parameters<-CurveFit1(Data_Quantified) ## End(Not run)
This function determines the best curve fit for each protein using the data post correction and also determines the R squared for each curve fit
CurveFit2(Data_Corrected)CurveFit2(Data_Corrected)
Data_Corrected |
data that meets exclusion criteria from Exclude function |
Curve fits and R squared for each protein
## Not run: Data_CurveFit2_Control<-CurveFit2(Data_Corrected_Control) ## End(Not run)## Not run: Data_CurveFit2_Control<-CurveFit2(Data_Corrected_Control) ## End(Not run)
This function imports data that will be analyzed in downstream functions.
Import(NControl, NCondition, Directory)Import(NControl, NCondition, Directory)
NControl |
the number of Control replicate experiments that are to be analyzed |
NCondition |
the number of Condition replicate experiments that are to be analyzed |
Directory |
the directory where the source data files to be analyzed are saved. This is also the location where the results will be saved. |
Imported data from all experiments
## Not run: Data_Imported<-Import(NControl,NCondition,Directory) ## End(Not run)## Not run: Data_Imported<-Import(NControl,NCondition,Directory) ## End(Not run)
This function is the primary function that calls other functions in the program.
InflectSSP( Directory, NControl, NCondition, PSM, UP, CurveRsq, PValMelt, PValMeltFDR, MeltLimit, RunSTRING, STRINGScore, Species )InflectSSP( Directory, NControl, NCondition, PSM, UP, CurveRsq, PValMelt, PValMeltFDR, MeltLimit, RunSTRING, STRINGScore, Species )
Directory |
the directory where the source data files to be analyzed are saved. This is also the location where the results will be saved. |
NControl |
the number of Control replicate experiments that are to be analyzed |
NCondition |
the number of Condition replicate experiments that are to be analyzed |
PSM |
the number of peptide spectrum matches that are deemed acceptable for reporting |
UP |
the number of unique peptides for a protein that are deemed acceptable for reporting |
CurveRsq |
Coefficient of determination criteria for melt curves |
PValMelt |
p-value criteria for melt shifts |
PValMeltFDR |
Whether or not the FDR correction for pvalue is used in designation of melts of interest |
MeltLimit |
the melt shift temperature limit used for determining which proteins to report as significant |
RunSTRING |
whether or not the STRING function will be run or not in the analysis |
STRINGScore |
the score to be used in the STRING analysis |
Species |
species number for bioinformatics search |
the proteins that have significant melt shifts from an experiment
## Not run: Directory<-'/Users/Einstein' NControl<-2 NCondition<-3 PSM<-2 UP<-3 CurveRsq<-.95 PValMelt<-0.05 PValMeltFDR<-"No" MeltLimit<-3 RunSTRING<-"Yes" STRINGScore<-0.99 Species<-9606 InflectSSP(Directory,NControl, NCondition,PSM,UP,CurveRsq,PValMelt,PValMeltFDR, MeltLimit,RunSTRING,STRINGScore, Species) ## End(Not run)## Not run: Directory<-'/Users/Einstein' NControl<-2 NCondition<-3 PSM<-2 UP<-3 CurveRsq<-.95 PValMelt<-0.05 PValMeltFDR<-"No" MeltLimit<-3 RunSTRING<-"Yes" STRINGScore<-0.99 Species<-9606 InflectSSP(Directory,NControl, NCondition,PSM,UP,CurveRsq,PValMelt,PValMeltFDR, MeltLimit,RunSTRING,STRINGScore, Species) ## End(Not run)
This function determines melt shifts for all proteins that meet quality criteria and also determines the melt shift p-values
MeltCalc( Directory, Data_CurveFit2_Complete_Unique, CurveRsq, PValMelt, MeltLimit, PValMeltFDR )MeltCalc( Directory, Data_CurveFit2_Complete_Unique, CurveRsq, PValMelt, MeltLimit, PValMeltFDR )
Directory |
the directory data is saved to |
Data_CurveFit2_Complete_Unique |
the curve fit data from the CurveFit2 function |
CurveRsq |
the criteria for melt curve p-values |
PValMelt |
the criteria for the melt shift p-values |
MeltLimit |
the melt shift temperature limit used for determining which proteins are significant |
PValMeltFDR |
Whether or not the FDR correction for pvalue is used in designation of melts of interest |
Proteins melt shifts
## Not run: Data_Melts<-MeltCalc(Directory,Data_CurveFit2_Complete_Unique, CurveRsq,PValMelt,MeltLimit,PValMeltFDR) ## End(Not run)## Not run: Data_Melts<-MeltCalc(Directory,Data_CurveFit2_Complete_Unique, CurveRsq,PValMelt,MeltLimit,PValMeltFDR) ## End(Not run)
This function normalizes the abundance values to that measured at the lowest temperature
Normalize(Data_Imported)Normalize(Data_Imported)
Data_Imported |
the abundance data imported from Import function |
Normalized data
## Not run: Data_Normalized<-Normalize(Data_Imported) ## End(Not run)## Not run: Data_Normalized<-Normalize(Data_Imported) ## End(Not run)
This function determines the median abundance value across the proteome for all experiments together
Quantify(Data_Normalized, NReps)Quantify(Data_Normalized, NReps)
Data_Normalized |
the normalized abundance data calculated in the Normalize function |
NReps |
the number of replicates to be analyzed |
The median abundance data for all experiments at the proteome level
## Not run: Data_Quantified<-Quantify(Data_Normalized) ## End(Not run)## Not run: Data_Quantified<-Quantify(Data_Normalized) ## End(Not run)
This function generates results from the Inflect function after applying criteria input from the user
ReportDataMelts( Data_Melts, Data_CurveFit2_Control, Data_CurveFit2_Condition, Directory, PValMelt )ReportDataMelts( Data_Melts, Data_CurveFit2_Control, Data_CurveFit2_Condition, Directory, PValMelt )
Data_Melts |
abundance and fit data for proteins that meet quality criteria in overall workflow |
Data_CurveFit2_Control |
the curve fit data from the Curve Fit 2 function |
Data_CurveFit2_Condition |
the curve fit data from the Curve Fit 2 function |
Directory |
directory where data is saved |
PValMelt |
the criteria for the melt shift p-values |
Excel files with summary of data along with melt curve plots for significant proteins
## Not run: ReportDataMelts(Data_Melts,Data_CurveFit2_Control,Data_CurveFit2_Condition,Directory,PValMelt) ## End(Not run)## Not run: ReportDataMelts(Data_Melts,Data_CurveFit2_Control,Data_CurveFit2_Condition,Directory,PValMelt) ## End(Not run)
This function generates a STRING based network using the significant melt shifts from analysis
ReportSTRING(Data_Melts, STRINGScore, Directory, Species, PValMeltFDR)ReportSTRING(Data_Melts, STRINGScore, Directory, Species, PValMeltFDR)
Data_Melts |
abundance and fit data for proteins that meet quality criteria in overall workflow |
STRINGScore |
the STRING score that is used to determine whether an interaction is significant |
Directory |
directory where results are saved |
Species |
species taxon number for bioinformatics search |
PValMeltFDR |
Whether or not the FDR correction for pvalue is used in designation of melts of interest |
Excel files with summary of data along with melt curve plots for significant proteins
## Not run: ReportSTRING(Data_Melts,STRINGScore,Directory,Species,PValMeltFDR) ## End(Not run)## Not run: ReportSTRING(Data_Melts,STRINGScore,Directory,Species,PValMeltFDR) ## End(Not run)